@@ -29,9 +29,9 @@ def hc_vals(pv, alpha=0.25, minPv='1/n', stbl=True):
 
     """
     EPS = 0.001
-    pv = np.asarray(pv)
+    pv = np.asarray(pv).copy()
     n = len(pv)  #number of features
-    pv[~np.isnan(pv)] = 1-EPS
+    pv[np.isnan(pv)] = 1-EPS
     #n = len(pv)
     hc_star = np.nan
     p_star = np.nan
